@@ -8,9 +8,10 @@ from enum import Enum
 class MLModelType(Enum):
     XGB = "xgb"
     XGB_QUANTILE = "xgb_quantile"
+    XGB_MULTIOUTPUT_QUANTILE = "xgb_multioutput_quantile"
     LGB = "lgb"
     LINEAR = "linear"
-    ProLoaf = "proloaf"
+    LINEAR_QUANTILE = "linear_quantile"
     ARIMA = "arima"
 
 
@@ -21,12 +22,6 @@ class ForecastType(Enum):
     BASECASE = "basecase"
 
 
-class TracyJobResult(Enum):
-    SUCCESS = "success"
-    FAILED = "failed"
-    UNKNOWN = "unknown"
-
-
 class PipelineType(Enum):
     FORECAST = "forecast"
     TRAIN = "train"
