@@ -39,7 +39,6 @@ def generate_holiday_feature_functions(
         - Bouwvak
         - Zomervakantie
         - Voorjaarsvakantie
-
         - Nieuwjaarsdag
         - Pasen
         - Koningsdag
@@ -61,7 +60,14 @@ def generate_holiday_feature_functions(
     """
     if years is None:
         now = datetime.now()
-        years = [now.year - 1, now.year]
+        years = [
+            now.year - 4,
+            now.year - 3,
+            now.year - 2,
+            now.year - 1,
+            now.year,
+            now.year + 1,
+        ]
 
     country_holidays = holidays.country_holidays(country, years=years)
 
@@ -157,6 +163,10 @@ def check_for_bridge_day(
     """
     country_holidays = holidays.country_holidays(country, years=years)
 
+    # if the date is a holiday, it is not a bridgeday
+    if date in country_holidays:
+        return holiday_functions, bridge_days
+
     # Define function explicitely to mitigate 'late binding' problem
     def make_holiday_func(requested_date):
         return lambda x: np.isin(x.index.date, np.array([requested_date]))
@@ -170,10 +180,11 @@ def check_for_bridge_day(
     is_holiday_tommorow = (date + timedelta(days=1)) in country_holidays
     is_weekend_tommorrow = (date + timedelta(days=1)).weekday() in [5, 6]
 
-    if (is_holiday_in_two_days or is_saturday_in_two_days) and (
-        not is_holiday_tommorow and not is_weekend_tommorrow
+    if (
+        (is_holiday_in_two_days or is_saturday_in_two_days)
+        and (not is_holiday_tommorow and not is_weekend_tommorrow)
+        and date not in country_holidays
     ):
-
         # Create feature function for each holiday
         holiday_functions.update(
             {
@@ -185,7 +196,7 @@ def check_for_bridge_day(
         )
         bridge_days.append((date + timedelta(days=1)))
 
-    # Looking backward: If day before yesterday is a national holiday
+    # Looking backward: If the day before is a national holiday
     # or a sunday check if yesterday is a national holiday
     is_saturday_two_days_ago = (date - timedelta(days=2)).weekday() == 6
     is_holiday_two_days_ago = (date - timedelta(days=2)) in country_holidays
@@ -195,7 +206,6 @@ def check_for_bridge_day(
     if (is_saturday_two_days_ago or is_holiday_two_days_ago) and (
         not is_holiday_yesterday and not is_weekend_yesterday
     ):
-
         # Create featurefunction for the bridge function
         holiday_functions.update(
             {
