@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 import copy
-from datetime import datetime
+from datetime import datetime, timezone
 from typing import Any, Callable, Optional
 
 import optuna
@@ -59,7 +59,7 @@ class RegressorObjective:
         self.validation_data = None
         self.test_data = None
         self.model = model
-        self.start_time = datetime.utcnow()
+        self.start_time = datetime.now(timezone.utc)
         self.test_fraction = test_fraction
         self.validation_fraction = validation_fraction
         self.eval_metric = eval_metric
@@ -94,7 +94,7 @@ class RegressorObjective:
         split_args = self.split_args
         if split_args is None:
             split_args = {
-                "stratification_min_max": self.model_type != MLModelType.ProLoaf,
+                "stratification_min_max": True,
                 "back_test": True,
             }
         (
@@ -349,13 +349,13 @@ class XGBQuantileRegressorObjective(RegressorObjective):
         )
 
 
-class ProLoafRegressorObjective(RegressorObjective):
+class XGBMultioutputQuantileRegressorObjective(RegressorObjective):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.model_type = MLModelType.ProLoaf
+        self.model_type = MLModelType.XGB_QUANTILE
 
     def get_params(self, trial: optuna.trial.FrozenTrial) -> dict:
-        """Get parameters for ProLoaf Regressor Objective with objective specific parameters.
+        """Get parameters for XGB Multioutput Quantile Regressor Objective with objective specific parameters.
 
         Args: trial
 
@@ -366,33 +366,16 @@ class ProLoafRegressorObjective(RegressorObjective):
         # Filtered default parameters
         model_params = super().get_params(trial)
 
-        # ProLoaf specific parameters
+        # XGB specific parameters
         params = {
-            # TODO: look into optimizing this pipeline for proloaf
-            # "relu_leak": trial.suggest_float("relu_leak", 0.1, 1.0),
-            # "core_layers": trial.suggest_int("core_layers", 1, 3),
-            # "rel_linear_hidden_size": trial.suggest_float(
-            #    "rel_linear_hidden_size", 0.1, 1
-            # ),
-            # "rel_core_hidden_size": trial.suggest_float("rel_core_hidden_size", 0.1, 1),
-            # "dropout_fc": trial.suggest_float("dropout_fc", 0.1, 0.9),
-            # "dropout_core": trial.suggest_float("dropout_core", 0.1, 0.9),
-            # "early_stopping_patience": trial.suggest_int(
-            #    "early_stopping_patience", 5, 10
-            # ),
-            # "early_stopping_margin": trial.suggest_float(
-            #    "early_stopping_margin", 0.1, 0.9
-            # ),
-            "max_epochs": trial.suggest_int(
-                "max_epochs", 1, 1
-            ),  # TODO: change after having availability to gpu resource
-            "batch_size": trial.suggest_int("batch_size", 1, 24),
+            "gamma": trial.suggest_float("gamma", 1e-8, 1.0),
+            "arctan_smoothing": trial.suggest_float("arctan_smoothing", 0.025, 0.15),
         }
         return {**model_params, **params}
 
     def get_pruning_callback(self, trial: optuna.trial.FrozenTrial):
-        return optuna.integration.PyTorchLightningPruningCallback(
-            trial, monitor="val_loss"
+        return optuna.integration.XGBoostPruningCallback(
+            trial, observation_key=f"validation_1-{self.eval_metric}"
         )
 
 
