@@ -72,8 +72,9 @@ class StandardDeviationGenerator:
         # For the time starts with 00, 01, 02, etc. TODO (MAKE MORE ELEGANT SOLUTION THAN A LOOP)
         for hour in range(24):
             hour_error = error[error.index == hour]
-            result["stdev"].iloc[hour] = np.std(hour_error)
-            result["hour"].iloc[hour] = hour
+
+            result.loc[hour, "stdev"] = np.std(hour_error)
+            result.loc[hour, "hour"] = hour
 
         result = result.astype("float")
 
