@@ -1,6 +1,7 @@
 # SPDX-FileCopyrightText: 2017-2023 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+import logging
 from typing import Union
 
 import pandas as pd
@@ -8,6 +9,8 @@ import pymsteams
 import structlog
 from pymsteams import cardsection
 
+from openstef.settings import Settings
+
 
 def post_teams(
     msg: Union[str, dict],
@@ -38,6 +41,14 @@ def post_teams(
     Note:
         This function is namespace-specific.
     """
+    if not Settings.post_teams_messages:
+        return
+
+    structlog.configure(
+        wrapper_class=structlog.make_filtering_bound_logger(
+            logging.getLevelName(Settings.log_level)
+        )
+    )
     logger = structlog.get_logger(__name__)
     # If no url is passed, give warning and don't send teams message
     if url is None:
