@@ -1,17 +1,19 @@
 # SPDX-FileCopyrightText: 2017-2023 Contributors to the OpenSTEF project <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
+import logging
+import math
 from datetime import datetime, timedelta
 from typing import Union
 
-import math
 import numpy as np
 import pandas as pd
 import structlog
 
 from openstef.exceptions import InputDataOngoingZeroFlatlinerError
-from openstef.preprocessing.preprocessing import replace_repeated_values_with_nan
 from openstef.model.regressors.regressor import OpenstfRegressor
+from openstef.preprocessing.preprocessing import replace_repeated_values_with_nan
+from openstef.settings import Settings
 
 
 def validate(
@@ -37,7 +39,15 @@ def validate(
     Returns:
         Dataframe where repeated values are set to None
 
+    Raises:
+        InputDataOngoingZeroFlatlinerError: If all recent load measurements are zero.
+
     """
+    structlog.configure(
+        wrapper_class=structlog.make_filtering_bound_logger(
+            logging.getLevelName(Settings.log_level)
+        )
+    )
     logger = structlog.get_logger(__name__)
 
     if not isinstance(data.index, pd.DatetimeIndex):
@@ -62,7 +72,7 @@ def validate(
 
     # Drop 'false' measurements. e.g. where load appears to be constant.
     data = replace_repeated_values_with_nan(
-        data, max_length=flatliner_threshold_repetitions, column_name=data.columns[0]
+        data, threshold=flatliner_threshold_repetitions, column_name=data.columns[0]
     )
     num_repeated_values = len(data) - len(data.iloc[:, 0].dropna())
     if num_repeated_values > 0:
@@ -81,6 +91,11 @@ def validate(
 
 
 def drop_target_na(data: pd.DataFrame) -> pd.DataFrame:
+    structlog.configure(
+        wrapper_class=structlog.make_filtering_bound_logger(
+            logging.getLevelName(Settings.log_level)
+        )
+    )
     logger = structlog.get_logger(__name__)
     len_original = len(data)
     # Remove where load is NA, NaN features are preserved
@@ -119,6 +134,11 @@ def is_data_sufficient(
     else:
         weights = model.feature_importance_dataframe
 
+    structlog.configure(
+        wrapper_class=structlog.make_filtering_bound_logger(
+            logging.getLevelName(Settings.log_level)
+        )
+    )
     logger = structlog.get_logger(__name__)
     # Set output variable
     is_sufficient = True
@@ -251,6 +271,11 @@ def calc_completeness_dataframe(
         Dataframe with fraction of completeness per column
 
     """
+    structlog.configure(
+        wrapper_class=structlog.make_filtering_bound_logger(
+            logging.getLevelName(Settings.log_level)
+        )
+    )
     logger = structlog.get_logger(__name__)
 
     if homogenise and isinstance(df.index, pd.DatetimeIndex) and len(df) > 0:
